package Bundle::Locale::CLDR::Americas;

use version;

our $VERSION = version->declare('v0.46.0');

=head1 NAME

Bundle::Locale::CLDR::Americas

=head1 CONTENTS

Locale::CLDR::Locales::Es 0.46.0

Bundle::Locale::CLDR::Caribbean 0.46.0

Locale::CLDR::Locales::Es::Latn 0.46.0

Bundle::Locale::CLDR::Latinamerica 0.46.0

Bundle::Locale::CLDR::Northamerica 0.46.0

Bundle::Locale::CLDR::Southamerica 0.46.0

Bundle::Locale::CLDR::Centralamerica 0.46.0

Locale::CLDR::Locales::Es::Latn::419 0.46.0

Bundle::Locale::CLDR::Northernamerica 0.46.0


=cut

1;

